import appService from './app.service.js'
import Vue from 'vue'
import Vuex from 'vuex'

Vue.use(Vuex)

export default new Vuex.Store({
  state: {
    books: []
  },
  getters: {
  },

  mutations: {
    SET_BOOK_LIST: (state, books) => {
        state.books = books
    },
    ADD_BOOK: (state, book) => {
        state.books.push(book)
    },
    UPDATE_BOOK: (state, book) => {
        for (let item of state.books) {
          if (item.id == book.id) {
            Object.assign(item, book)
            return
          }
        }
        throw "No book was found by that id"

    },
  }, //mutations
  actions: {
    LOAD_BOOKS_LIST({commit}) {
        return new Promise((resolve, reject) => {
            appService.getAllBooks()
                .then((data) => {
                  commit('SET_BOOK_LIST', data.books)
                  resolve(data)
                })
                .catch(error => {
                  reject(error)
                })

        }
        )
    },
    POST_BOOK(context, book){
        return new Promise((resolve, reject) => {
            appService.addBook(book)
                .then((data) => {
                    context.commit('ADD_BOOK', book)
                    resolve()
                    })
                .catch((data) => {
                    console.log(data)
                    reject()
                })
        })
    },
    PUT_BOOK(context, book){
      return new Promise((resolve, reject) => {
        appService.updateBook(book)
          .then(data => {
            context.commit('UPDATE_BOOK', book)
            resolve()
          })
          .catch(data => {
            console.log(data)
            reject()
          })
      })
    }
  },//actions
})
